@@ -104,14 +104,14 @@ draw_simple_image(GtkStyle       *style,
   
   if ((width == -1) && (height == -1))
     {
-      gdk_window_get_size(window, &width, &height);
+      gdk_drawable_get_size(window, &width, &height);
       if (allow_setbg)
       	setbg = TRUE;
     }
   else if (width == -1)
-    gdk_window_get_size(window, &width, NULL);
+    gdk_drawable_get_size(window, &width, NULL);
   else if (height == -1)
-    gdk_window_get_size(window, NULL, &height);
+    gdk_drawable_get_size(window, NULL, &height);
 
   if (!(match_data->flags & THEME_MATCH_ORIENTATION))
     {
@@ -167,13 +167,13 @@ draw_gap_image(GtkStyle       *style,
   
   if ((width == -1) && (height == -1))
     {
-      gdk_window_get_size(window, &width, &height);
+      gdk_drawable_get_size(window, &width, &height);
       setbg = TRUE;
     }
   else if (width == -1)
-    gdk_window_get_size(window, &width, NULL);
+    gdk_drawable_get_size(window, &width, NULL);
   else if (height == -1)
-    gdk_window_get_size(window, NULL, &height);
+    gdk_drawable_get_size(window, NULL, &height);
 
   if (!(match_data->flags & THEME_MATCH_ORIENTATION))
     {
@@ -594,9 +594,13 @@ draw_string (GtkStyle * style,
 	     gint y,
 	     const gchar * string)
 {
+  PangoLayout *layout = NULL;
+
   g_return_if_fail(style != NULL);
   g_return_if_fail(window != NULL);
 
+  layout = gtk_widget_create_pango_layout (widget, string);
+
   if (state == GTK_STATE_INSENSITIVE)
     {
       if (area)
@@ -605,7 +609,7 @@ draw_string (GtkStyle * style,
 	  gdk_gc_set_clip_rectangle(style->fg_gc[state], area);
 	}
 
-      gdk_draw_string(window, gtk_style_get_font (style), style->fg_gc[state], x, y, string);
+      gdk_draw_layout(GTK_DRAWABLE (window), style->fg_gc[state], x, y, layout);
       
       if (area)
 	{
@@ -616,7 +620,7 @@ draw_string (GtkStyle * style,
   else
     {
       gdk_gc_set_clip_rectangle(style->fg_gc[state], area);
-      gdk_draw_string(window, gtk_style_get_font (style), style->fg_gc[state], x, y, string);
+      gdk_draw_layout(GTK_DRAWABLE (window), style->fg_gc[state], x, y, layout);
       gdk_gc_set_clip_rectangle(style->fg_gc[state], NULL);
     }
 }
